@@ -1,12 +1,21 @@
-import requests
 import json
-
-from pydantic import BaseModel
-from requests import Response
-from typing import Dict
+from http import HTTPStatus
+import sys
+from typing import Any, Optional
 from urllib.parse import urljoin, urlencode
+
+import orjson
+from pydantic import BaseModel
+import requests
+from requests import Response
+
 from lago_python_client.version import LAGO_VERSION
 
+if sys.version_info < (3, 9):
+    from typing import MutableMapping
+else:
+    from collections.abc import MutableMapping
+
 
 class BaseClient:
     RESPONSE_SUCCESS_CODES = [200, 201, 202, 204]
@@ -15,7 +24,7 @@ class BaseClient:
         self.base_url = base_url
         self.api_key = api_key
 
-    def find(self, resource_id: str, params: Dict = None):
+    def find(self, resource_id: str, params: Optional[dict] = None):
         api_resource = self.api_resource() + '/' + resource_id
         query_url = urljoin(self.base_url, api_resource)
 
@@ -28,7 +37,7 @@ class BaseClient:
 
         return self.prepare_response(data)
 
-    def find_all(self, options: Dict = None):
+    def find_all(self, options: Optional[dict] = None):
         if options:
             api_resource = self.api_resource() + '?' + urlencode(options)
         else:
@@ -64,15 +73,7 @@ class BaseClient:
         else:
             return self.prepare_response(data.json().get(self.root_name()))
 
-    def delete(self, params: Dict):
-        query_url = urljoin(self.base_url, self.api_resource())
-        data = json.dumps(params)
-        api_response = requests.delete(query_url, data=data, headers=self.headers())
-        data = self.handle_response(api_response).json().get(self.root_name())
-
-        return self.prepare_response(data)
-
-    def update(self, input_object: BaseModel, identifier: str = None):
+    def update(self, input_object: BaseModel, identifier: Optional[str] = None):
         api_resource = self.api_resource()
 
         if identifier is not None:
@@ -99,19 +100,28 @@ class BaseClient:
 
         return headers
 
-    def handle_response(self, response: Response):
+    def handle_response(self, response: Response) -> Optional[Response]:
         if response.status_code in BaseClient.RESPONSE_SUCCESS_CODES:
             if response.text:
                 return response
             else:
                 return None
         else:
+            if response.text:
+                response_data: Any = orjson.loads(response.text)
+                detail: Optional[str] = getattr(response_data, 'error', None)
+            else:
+                response_data = None
+                detail = None
             raise LagoApiError(
-                "URI: %s. Status code: %s. Response: %s." % (
-                    response.request.url, response.status_code, response.text)
+                status_code=response.status_code,
+                url=response.request.url,
+                response=response_data,
+                detail=detail,
+                headers=response.headers,
             )
 
-    def prepare_index_response(self, data: Dict):
+    def prepare_index_response(self, data: dict):
         collection = []
 
         for el in data[self.api_resource()]:
@@ -126,4 +136,22 @@ class BaseClient:
 
 
 class LagoApiError(Exception):
-    ...
+    def __init__(
+        self,
+        status_code: int,
+        url: Optional[str],
+        response: Any,
+        detail: Optional[str] = None,
+        headers: Optional[MutableMapping[str, str]] = None,
+    ) -> None:
+        if detail is None:
+            detail = HTTPStatus(status_code).phrase
+        self.status_code = status_code
+        self.url = url
+        self.response = response
+        self.detail = detail
+        self.headers = headers
+
+    def __repr__(self) -> str:
+        class_name = self.__class__.__name__
+        return f"{class_name}(status_code={self.status_code!r}, detail={self.detail!r})"
