@@ -5,6 +5,7 @@ from tests.test_applied_coupon_client import TestAppliedCouponClient
 from tests.test_applied_add_on_client import TestAppliedAddOnClient
 from tests.test_billable_metric_client import TestBillableMetricClient
 from tests.test_coupon_client import TestCouponClient
+from tests.test_group_client import TestGroupClient
 from tests.test_plan_client import TestPlanClient
 from tests.test_add_on_client import TestAddOnClient
 from tests.test_organization_client import TestOrganizationClient
@@ -13,3 +14,4 @@ from tests.test_webhook_client import TestWebhookClient
 from tests.test_client import TestClient
 from tests.test_wallet_client import TestWalletClient
 from tests.test_wallet_transaction_client import TestWalletTransactionClient
+from tests.test_credit_note_client import TestCreditNoteClient
