@@ -3,7 +3,7 @@ import requests_mock
 import os
 
 from lago_python_client.client import Client
-from lago_python_client.models import Customer, BillingConfiguration
+from lago_python_client.models import Customer, CustomerBillingConfiguration
 from lago_python_client.clients.base_client import LagoApiError
 
 
@@ -11,9 +11,13 @@ def create_customer():
     return Customer(
         external_id='5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba',
         name='Gavin Belson',
-        billing_configuration=BillingConfiguration(
+        currency='EUR',
+        billing_configuration=CustomerBillingConfiguration(
+            invoice_grace_period=3,
             payment_provider='stripe',
-            provider_customer_id='cus_12345'
+            provider_customer_id='cus_12345',
+            sync_with_provider=True,
+            vat_rate=12.5
         )
     )
 
@@ -35,8 +39,12 @@ class TestCustomerClient(unittest.TestCase):
         self.assertEqual(response.external_id, '5eb02857-a71e-4ea2-bcf9-57d3a41bc6ba')
         self.assertEqual(response.name, 'Gavin Belson')
         self.assertEqual(response.email, 'dinesh@piedpiper.test')
+        self.assertEqual(response.currency, 'EUR')
+        self.assertEqual(response.billing_configuration.invoice_grace_period, 3)
         self.assertEqual(response.billing_configuration.payment_provider, 'stripe')
         self.assertEqual(response.billing_configuration.provider_customer_id, 'cus_12345')
+        self.assertEqual(response.billing_configuration.sync_with_provider, True)
+        self.assertEqual(response.billing_configuration.vat_rate, 12.5)
 
     def test_invalid_create_customers_request(self):
         client = Client(api_key='invalid')
@@ -57,7 +65,7 @@ class TestCustomerClient(unittest.TestCase):
                            text=mock_response('customer_usage'))
             response = client.customers().current_usage('external_customer_id', '123')
 
-        self.assertEqual(response.from_date, '2022-07-01')
+        self.assertEqual(response.from_datetime, '2022-07-01T00:00:00Z')
         self.assertEqual(len(response.charges_usage), 1)
         self.assertEqual(response.charges_usage[0].units, 1.0)
 
